@@ -40,4 +40,13 @@ def bool_in_correction(ampt, cor_thd, offset):
         return True
     else:
         return False
-    
\ No newline at end of file
+
+def bool_is_rule(ampt, rule, thd):
+    if(rule == 'g'):
+        return ampt > thd
+    if(rule == 'ge'):
+        return ampt >= thd
+    if(rule == 'le'):
+        return ampt <= thd
+    if(rule == 'l'):
+        return ampt < thd
\ No newline at end of file
